==> haskell-criterion-1.1.1.0-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.1.1.0
id: criterion-1.1.1.0-9zX4f1smVmVB4xRpvOP8j
key: criterion-1.1.1.0-9zX4f1smVmVB4xRpvOP8j
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: 5a85295b153ce2398772a2cc1d824426
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.1.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/criterion-1.1.1.0
hs-libraries: HScriterion-1.1.1.0-9zX4f1smVmVB4xRpvOP8j
depends:
    Glob-0.7.10-IZweMtCmNS9DHvlyBIWXK9
    aeson-0.11.2.0-DnLQZoUJi9MGazkzDpLR7l
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1
    cassava-0.4.5.0-IcYlRGX4eV78lXxFSCuD0j containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    hastache-0.6.1-1MLAr6nLnVQ1dOgZDJbhHK
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    optparse-applicative-0.12.1.0-4FckWvtE7Gp1EYdm7OVbJw
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    statistics-0.13.3.0-k9aClBmq6O3JZAm0rsPnP
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.1.1.0-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.1.1.0
id: criterion-1.1.1.0-JcxwymbL2AHAZGtTHDHWUW
key: criterion-1.1.1.0-JcxwymbL2AHAZGtTHDHWUW
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: 3d60b5bf290873fae4a0d0a90f3b4ac2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.1.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/criterion-1.1.1.0
hs-libraries: HScriterion-1.1.1.0-JcxwymbL2AHAZGtTHDHWUW
depends:
    Glob-0.7.11-9NyQG65o63m9G1pgipTVtw
    aeson-0.11.2.0-BJFBIG7cfak4WE0j2VGFvV
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1
    cassava-0.4.5.0-IcYlRGX4eV78lXxFSCuD0j containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    hastache-0.6.1-1MLAr6nLnVQ1dOgZDJbhHK
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    optparse-applicative-0.12.1.0-4FckWvtE7Gp1EYdm7OVbJw
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    statistics-0.13.3.0-7jGOLLLJqFGCJwUhjPC6fE
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
